@@ -1,10 +1,11 @@
-# $Id: ex_mkvcard.rb,v 1.4 2005/01/02 17:18:06 sam Exp $
+# $Id: ex_mkvcard.rb,v 1.5 2005/02/04 21:32:31 sam Exp $
 
 require 'vpim/maker/vcard'
 
 card = Vpim::Maker::Vcard.make('Jimmy Death') do |card|
   card.add_name do |name|
     name.family = 'Death'
+    name.given = 'Jimmy'
     name.prefix = 'Dr.'
   end
 
@@ -38,15 +39,19 @@ card = Vpim::Maker::Vcard.make('Jimmy Death') do |card|
     photo.type = 'jpeg'
   end
 
-  card.add_tel('+416+123+1111')
+  card.add_tel('+416 123 1111')
 
-  card.add_tel('+416+123+2222') { |t| t.location = 'home'; t.preferred = true }
+  card.add_tel('+416 123 2222') { |t| t.location = 'home'; t.preferred = true }
 
   card.add_impp('joe') do |impp|
     impp.preferred = 'yes'
     impp.location = 'mobile'
   end
 
+  card.add_x_aim('example') do |xaim|
+    xaim.location = 'row12'
+  end
+
   card.add_tel('+416+123+3333') do |tel|
     tel.location = 'work'
     tel.capability = 'fax'
